rowan_nom

Function peek_neg

pub fn peek_neg<'slice, 'src: 'slice, Lang: Language, E, IE: RowanNomError<Lang>>(
    parser: impl Parser<Input<'slice, 'src, Lang>, Children<Lang, E>, IE>,
) -> impl FnMut(Input<'slice, 'src, Lang>) -> IResult<'slice, 'src, Lang, E, IE>
where Lang::Kind: 'static,
Negated peek, succeeds only if the given parser fails

  • On failure, succeeds with and empty Children and the same input
  • On success, fails