rowan_nom

Function t

pub fn t<'slice, 'src: 'slice, Lang: Language, E, IE: RowanNomError<Lang>>(
    token: Lang::Kind,
) -> impl FnMut(Input<'slice, 'src, Lang>) -> IResult<'slice, 'src, Lang, E, IE> + Clone + Copy
Parses only the given token, fails if the wrong token is read or if the input is empty

Trivia tokens are automatically skipped and prepended to the parsed token