rowan_nom

Struct Children

pub struct Children<Lang: Language, E> { /* private fields */ }
A partial green AST builder, used as an output for all parsers

The use of rowan in a parser generally implies that the parser should be as resilient as possible. That is, it shouldn’t return an error. This structure represents the output that a rowan-nom parser should return everywhere. It contains a list of rowan nodes or tokens, and a list of currently accumulated errors. This way, all parser can return Ok and are still able to emit errors.

Most of the time, Children will be built using one of this crate’s parsers.

Implementations

Source

impl<Lang: Language, E> Children<Lang, E>

pub fn empty() -> Self

pub fn from_err(error: E) -> Self

pub fn from_rowan_children(children: Children<'_>, errors: Vec<E>) -> Self

pub fn into_node(self, kind: Lang::Kind) -> Self

pub fn into_root_node(self, kind: Lang::Kind) -> (SyntaxNode<Lang>, Vec<E>)