pub fn eof<'slice, 'src: 'slice, Lang: Language, E, IE: RowanNomError<Lang>>(
input: Input<'slice, 'src, Lang>,
) -> IResult<'slice, 'src, Lang, E, IE>Expand description
Succeeds if the input contains no tokens other than trivia, and returns a Children object with said trivia, effectively emptying last insignificant bits of input