pub fn t_raw<'slice, 'src: 'slice, Lang: Language, E, IE: RowanNomError<Lang>>(
token: Lang::Kind,
) -> impl FnMut(Input<'slice, 'src, Lang>) -> IResult<'slice, 'src, Lang, E, IE> + Clone + CopyExpand description
Parses only the given token, fails if the wrong token is read or if the input is empty, but does not skip trivia tokens
This may be useful in situations were whitespace or comments are prohibited in a specific context