pub struct Children<Lang: Language, E> { /* private fields */ }Expand description
A partial green AST builder, used as an output for all parsers
The use of rowan in a parser generally implies that the parser should be as resilient as possible. That is, it shouldn’t return an error. This structure represents the output that a rowan-nom parser should return everywhere. It contains a list of rowan nodes or tokens, and a list of currently accumulated errors. This way, all parser can return Ok and are still able to emit errors.
Most of the time, Children will be built using one of this crate’s parsers.
Implementations